@@ -1,12 +1,12 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
 # Copyright (c) 2004 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
 #
-# This is the install script for eric4's translation files.
+# This is the install script for eric5's translation files.
 
 """
-Installation script for the eric4 IDE translation files.
+Installation script for the eric5 IDE translation files.
 """
 
 import sys
@@ -17,11 +17,12 @@ import glob
 from PyQt4.QtCore import QDir
 
 try:
-    from eric4config import getConfig
+    from eric5config import getConfig
 except ImportError:
-    print "The eric4 IDE doesn't seem to be installed. Aborting."
+    print("The eric5 IDE doesn't seem to be installed. Aborting.")
     sys.exit(1)
     
+
 def getConfigDir():
     """
     Global function to get the name of the directory storing the config data.
@@ -29,25 +30,26 @@ def getConfigDir():
     @return directory name of the config dir (string)
     """
     if sys.platform.startswith("win"):
-        cdn = "_eric4"
+        cdn = "_eric5"
     else:
-        cdn = ".eric4"
+        cdn = ".eric5"
         
     hp = QDir.homePath()
     dn = QDir(hp)
     dn.mkdir(cdn)
-    hp.append("/").append(cdn)
+    hp += "/" + cdn
     try:
-        return unicode(QDir.toNativeSeparators(hp))
+        return QDir.toNativeSeparators(hp)
     except AttributeError:
-        return unicode(QDir.convertSeparators(hp))
+        return QDir.convertSeparators(hp)
     
 # Define the globals.
 progName = None
 configDir = getConfigDir()
 privateInstall = False
 
-def usage(rcode = 2):
+
+def usage(rcode=2):
     """
     Display a usage message and exit.
 
@@ -55,15 +57,17 @@ def usage(rcode = 2):
     """
     global progName, configDir
 
-    print
-    print "Usage:"
-    print "    %s [-hp]" % (progName)
-    print "where:"
-    print "    -h        display this help message"
-    print "    -p        install into the private area (%s)" % (configDir)
+    print()
+    print("Usage:")
+    print("    {0} [-hp]".format(progName))
+    print("where:")
+    print("    -h        display this help message")
+    print("    -p        install into the private area ({0})".format(
+        configDir))
 
     sys.exit(rcode)
 
+
 def installTranslations():
     """
     Install the translation files into the right place.
@@ -79,11 +83,14 @@ def installTranslations():
         for fn in glob.glob(os.path.join('eric', 'i18n', '*.qm')):
             shutil.copy2(fn, targetDir)
             os.chmod(os.path.join(targetDir, os.path.basename(fn)), 0o644)
-    except IOError, msg:
-        sys.stderr.write('IOError: %s\nTry install-i18n as root.\n' % msg)
-    except OSError, msg:
-        sys.stderr.write('OSError: %s\nTry install-i18n with admin rights.\n' % msg)
+    except IOError as msg:
+        sys.stderr.write(
+            'IOError: {0}\nTry install-i18n as root.\n'.format(msg))
+    except OSError as msg:
+        sys.stderr.write(
+            'OSError: {0}\nTry install-i18n with admin rights.\n'.format(msg))
     
+
 def main(argv):
     """
     The main function of the script.
@@ -97,14 +104,12 @@ def main(argv):
     progName = os.path.basename(argv[0])
 
     try:
-        optlist, args = getopt.getopt(argv[1:],"hp")
+        optlist, args = getopt.getopt(argv[1:], "hp")
     except getopt.GetoptError:
         usage()
 
     global platBinDir
     
-    depChecks = 1
-
     for opt, arg in optlist:
         if opt == "-h":
             usage(0)
@@ -119,8 +124,7 @@ if __name__ == "__main__":
     except SystemExit:
         raise
     except:
-        print \
-"""An internal error occured.  Please report all the output of the program,
-including the following traceback, to eric4-bugs@eric-ide.python-projects.org.
-"""
+        print("""An internal error occured.  Please report all the output of"""
+              """ the program,\nincluding the following traceback, to"""
+              """ eric5-bugs@eric-ide.python-projects.org.\n""")
         raise
